#' Returns the base url of the nbp api.
nbp_api_base_url <- function() {
    "https://api.nbp.pl/api/"
}
